@@ -270,7 +270,7 @@ impl ModuleWriter for WheelWriter {
             zip::CompressionMethod::Deflated
         };
 
-        let mut options = zip::write::FileOptions::default()
+        let mut options = zip::write::SimpleFileOptions::default()
             .unix_permissions(permissions)
             .compression_method(compression_method);
         let mtime = self.mtime().ok();
@@ -379,7 +379,8 @@ impl WheelWriter {
             zip::CompressionMethod::Deflated
         };
 
-        let mut options = zip::write::FileOptions::default().compression_method(compression_method);
+        let mut options =
+            zip::write::SimpleFileOptions::default().compression_method(compression_method);
         let mtime = self.mtime().ok();
         if let Some(mtime) = mtime {
             options = options.last_modified_time(mtime);
@@ -1028,6 +1029,7 @@ fn uniffi_bindgen_command(crate_dir: &Path) -> Result<Command> {
 fn generate_uniffi_bindings(
     crate_dir: &Path,
     target_dir: &Path,
+    module_name: &str,
     target_os: Os,
     artifact: &Path,
 ) -> Result<UniFfiBindings> {
@@ -1037,6 +1039,7 @@ fn generate_uniffi_bindings(
         .normalize()?
         .join("maturin")
         .join("uniffi")
+        .join(module_name)
         .into_path_buf();
     fs::create_dir_all(&binding_dir)?;
 
@@ -1153,7 +1156,7 @@ pub fn write_uniffi_module(
         names: binding_names,
         cdylib,
         path: binding_dir,
-    } = generate_uniffi_bindings(crate_dir, target_dir, target_os, artifact)?;
+    } = generate_uniffi_bindings(crate_dir, target_dir, module_name, target_os, artifact)?;
 
     let py_init = binding_names
         .iter()
